@@ -565,6 +565,7 @@ class GffLoader {
 		bool BEDinput:1;
 		bool TLFinput:1;
 		bool keepGenes:1;
+		bool trAdoption:1; //orphan transcript adoption by the container gene
 		bool keepGff3Comments:1;
 		bool sortRefsAlpha:1;
 		bool doCluster:1;
@@ -628,7 +629,7 @@ class GffLoader {
 
 void printFasta(FILE* f, GStr& defline, char* seq, int seqlen=-1, bool useStar=false);
 
-void printTabFormat(FILE* f, GffObj* t);
+//void printTabFormat(FILE* f, GffObj* t);
 
 //"position" a given coordinate x within a list of transcripts sorted by their start (lowest)
 //coordinate, using quick-search; the returned int is the list index of the closest *higher*
